TransportConnector class

Constructors

TransportConnector(int port)

Properties

authority String
Header populated from any credentials or hostname information.
no setter
done Future
A future that completes when the client closes or when an error occurs.
no setter
hashCode int
The hash code for this object.
no setterinherited
port int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream MemoryStream
latefinal

Methods

connect() Future<ClientTransportConnection>
Creates a HTTP/2 client connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() → void
Shuts down the connection, which should at least close the client.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited